import Vue from 'vue'
import Vuex from 'vuex'

Vue.use(Vuex); //vue的插件机制

import api from '@/api/api.js'

//Vuex.Store 构造器选项
const store = new Vuex.Store({
	state: {
		configList: {}, //配置对象
		userInfo : {},
	},
	getters: {
		getConfig(state){
			return state.configList
		}
	},
	mutations: {
		// 初始化配置
		initConfig(state) {
			let config = ['preferential', 'wx']
			config.forEach(k => {
				api('getConfig', {
					keyValue : k
				}, res => {
					if (res.code == 200) {
						state.configList[k] = res.result
					}
				})
			})
			
			let apiConfig = [ 'getPrivacyPolicy' , 'getUserAgreement' ]		//需要访问不同接口才能得到的配置数据
			let key = ['privacyAgreement','userAgreement']
			apiConfig.forEach((item,index) => {
				api(item,res => {
					state.configList[key[index]] = res.result
				})
			})
		},
		login(state) {
			uni.login({
				success(res) {
					console.log(res);
					if (res.errMsg != "login:ok") {
						return
					}
					api('loginLogin', {
						code: res.code
					}, res => {
						if (res.code != 200) {
							return
						}

						state.userInfo = res.result.userInfo
						uni.setStorageSync('token', res.result.token)

						if (!state.userInfo.nickName || !state.userInfo.headImage) {
							uni.navigateTo({
								url: '/pages/login/wxUserInfo'
							})
						}else{
							uni.switchTab({
								url: '/pages/payment/payment'
							})
						}
						
					})
				},
				fail(err) {
					console.error(err)
				}
			})
		},
		getUserInfo(state) {
			api('infoGetInfo', res => {
				if(res.code == 200){
					state.userInfo = res.result
				}
			})
		},
	},
	actions: {},
})

export default store